@@ -4,6 +4,7 @@ use Moo;
 use Dancer2;
 
 extends 'Strehler::Element';
+with 'Strehler::Element::Role::Slugged';
 
 sub metaclass_data 
 {
@@ -16,4 +17,15 @@ sub metaclass_data
     return $element_conf{$param};
 }
 
+sub to_slug
+{
+    my $self = shift;
+    my $lan = shift;
+    return 'text';
+}
+
+sub multilang_slug
+{
+    return 0;
+}
 1;
